@@ -3,7 +3,7 @@
 // -----------------------------------------------------------------------
 // This file is part of Igloo
 //
-// Copyright (C) 2003, 2005 Barnraiser
+// Copyright (C) 2003, 2006 Barnraiser
 // http://www.barnraiser.org/
 // info@barnraiser.org
 //
@@ -128,17 +128,12 @@ $lang['txt_tipped'] =							"tipped";
 $lang['txt_item_options'] =						"item options";
 $lang['txt_votes'] = 							"votes";
 $lang['txt_comment_datetime'] =					"Comment date and time";
-$lang['sub_check_spelling'] =					"Check Spelling";
 $lang['txt_history'] = 							"history";
 $lang['txt_degree_nw'] = 						"network";
 $lang['txt_publish_all'] = 						"everyone";
 $lang['txt_profile_nic'] = 						"nic";
 $lang['txt_profile_session_status'] = 			"status";
 $lang['txt_last_edited'] = 						"last edited";
-$lang['txt_option_group'] = 					"latest from the group";
-$lang['txt_option_network'] = 					"latest from my network";
-$lang['txt_option_mark'] = 						"mark this";
-$lang['txt_option_tip'] = 						"tip this";
 $lang['txt_list_nav_start'] = 					"start";
 $lang['txt_list_nav_end'] = 					"end";
 $lang['txt_list_nav_prev'] = 					"previous";
